@@ -265,6 +265,100 @@ cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
 END_OF_TEST_RESULTS
 
 
+##### Test tests/split #####
+
+runtest() {
+local dom1="$1"
+local dom2="$2"
+$src/cvm-testclient $src/cvm-vmailmgr virt$dom1 "$dom2" pass
+}
+run_compare_test tests/split '' '' <<END_OF_TEST_RESULTS
+user name:        virt
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/virt
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           noathost
+mailbox path:     @TMPDIR@/virt
+END_OF_TEST_RESULTS
+
+run_compare_test tests/split '' 'test.tld' <<END_OF_TEST_RESULTS
+user name:        virt
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/virt
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           test.tld
+mailbox path:     @TMPDIR@/virt
+END_OF_TEST_RESULTS
+
+run_compare_test tests/split '' 'other.tld' <<END_OF_TEST_RESULTS
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+END_OF_TEST_RESULTS
+
+run_compare_test tests/split '@test.tld' '' <<END_OF_TEST_RESULTS
+user name:        virt
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/virt
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           test.tld
+mailbox path:     @TMPDIR@/virt
+END_OF_TEST_RESULTS
+
+run_compare_test tests/split '@test.tld' 'test.tld' <<END_OF_TEST_RESULTS
+user name:        virt
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/virt
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           test.tld
+mailbox path:     @TMPDIR@/virt
+END_OF_TEST_RESULTS
+
+run_compare_test tests/split '@test.tld' 'other.tld' <<END_OF_TEST_RESULTS
+user name:        virt
+user ID:          @UID@
+group ID:         @GID@
+real name:        (null)
+directory:        @TMPDIR@/virt
+shell:            (null)
+group name:       (null)
+system user name: user
+system directory: @TMPDIR@
+domain:           test.tld
+mailbox path:     @TMPDIR@/virt
+END_OF_TEST_RESULTS
+
+run_compare_test tests/split '@other.tld' '' <<END_OF_TEST_RESULTS
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+END_OF_TEST_RESULTS
+
+run_compare_test tests/split '@other.tld' 'test.tld' <<END_OF_TEST_RESULTS
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+END_OF_TEST_RESULTS
+
+run_compare_test tests/split '@other.tld' 'other.tld' <<END_OF_TEST_RESULTS
+cvm-testclient: Fatal: Authentication failed, error #100 (Credentials rejected)
+END_OF_TEST_RESULTS
+
+
 ##### Test tests/sasl-eof #####
 
 runtest() {
